package com.syc.slm.slmbi.controller;

import com.syc.slm.common.core.util.R;
import com.syc.slm.slmbi.dto.InstrumentPanelPermissionDTO;
import com.syc.slm.slmbi.service.InstrumentPanelPermissionService;
import com.syc.slm.slmbi.vo.InstrumentPanelPermissionVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * slm-bi
 * 仪表板权限控制
 *
 * @author : lin
 * @date : 2021-03-25 18:54
 **/
@Api(value = "仪表板权限控制")
@RestController
@RequestMapping("/panel-permissions")
public class InstrumentPanelPermissionController {

    @Autowired
    private InstrumentPanelPermissionService instrumentPanelPermissionService;

    @PostMapping
    @ApiOperation("保存仪表板权限（列表的属性保存）")
    public R<String> savePermission(@RequestBody List<InstrumentPanelPermissionDTO> permissions) {
        return R.ok(instrumentPanelPermissionService.savePermission(permissions));
    }

    @PostMapping("/{panelId}/to-copy")
    @ApiOperation("从其他仪表板复制配置")
    @ApiImplicitParam(name = "panelId", value = "其他仪表板id", required = true)
    public R<List<InstrumentPanelPermissionVo>> saveCopyOtherPermission(@PathVariable String panelId) {
        return R.ok(instrumentPanelPermissionService.saveCopyOtherPermission(panelId));
    }

    @PostMapping("/{panelId}/copy-to")
    @ApiOperation("将仪表板权限复制给其他仪表板")
    @ApiImplicitParam(name = "panelId", value = "其他仪表板id", required = true)
    public R<String> saveCopyToOtherPermission(@RequestBody List<InstrumentPanelPermissionDTO> permissions,
        @PathVariable String panelId) {
        return R.ok(instrumentPanelPermissionService.saveCopyToOtherPermission(permissions, panelId));
    }

    @GetMapping("/{panelId}")
    @ApiOperation("根据仪表板id获取仪表板权限")
    @ApiImplicitParam(name = "panelId", value = "仪表板id", required = true)
    public R<List<InstrumentPanelPermissionVo>> selectPermissionByPanelId(@PathVariable String panelId) {
        return R.ok(instrumentPanelPermissionService.selectPermissionByPanelId(panelId));
    }
}
